"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Relationships = exports.Entities = exports.Steps = exports.IngestionSources = exports.ACCOUNT_ENTITY = void 0;
const integration_sdk_core_1 = require("@jupiterone/integration-sdk-core");
const entity_definitions_1 = require("./entity-definitions");
exports.ACCOUNT_ENTITY = 'account-entity';
exports.IngestionSources = {
    USERS: 'users',
    GROUPS: 'groups',
    PROJECTS: 'projects',
    MERGE_REQUESTS: 'merge-requests',
    COMMITS: 'commits',
    FINDINGS: 'findings',
    PROJECT_LABELS: 'project-labels',
    BRANCH_RULES: 'branch-rules',
};
exports.Steps = {
    ACCOUNTS: 'fetch-accounts',
    USERS: 'fetch-users',
    GROUPS: 'fetch-groups',
    PROJECTS: 'fetch-projects',
    MERGE_REQUESTS: 'fetch-merge-requests',
    COMMITS: 'fetch-mr-commits',
    FINDINGS: 'fetch-vulnerability-findings',
    PROJECT_LABELS: 'fetch-project-labels',
    BRANCH_RULES: 'fetch-branch-rules',
};
exports.Entities = {
    ACCOUNT: entity_definitions_1.ENTITY_ACCOUNT,
    USER: entity_definitions_1.ENTITY_USER,
    GROUP: entity_definitions_1.ENTITY_GROUP,
    FINDING: entity_definitions_1.ENTITY_FINDING,
    MERGE_REQUEST: entity_definitions_1.ENTITY_MERGE_REQUEST,
    COMMIT: entity_definitions_1.ENTITY_COMMIT,
    PROJECT: entity_definitions_1.ENTITY_PROJECT,
    LABEL: entity_definitions_1.ENTITY_PROJECT_LABEL,
    BRANCH_RULE: entity_definitions_1.ENTITY_BRANCH_RULE,
};
exports.Relationships = {
    ACCOUNT_HAS_PROJECT: {
        _type: 'gitlab_account_has_project',
        sourceType: exports.Entities.ACCOUNT._type,
        _class: integration_sdk_core_1.RelationshipClass.HAS,
        targetType: exports.Entities.PROJECT._type,
    },
    ACCOUNT_HAS_GROUP: {
        _type: 'gitlab_account_has_group',
        sourceType: exports.Entities.ACCOUNT._type,
        _class: integration_sdk_core_1.RelationshipClass.HAS,
        targetType: exports.Entities.GROUP._type,
    },
    PROJECT_HAS_USER: {
        _type: 'gitlab_project_has_user',
        sourceType: exports.Entities.PROJECT._type,
        _class: integration_sdk_core_1.RelationshipClass.HAS,
        targetType: exports.Entities.USER._type,
    },
    GROUP_HAS_SUBGROUP: {
        _type: 'gitlab_group_has_group',
        sourceType: exports.Entities.GROUP._type,
        _class: integration_sdk_core_1.RelationshipClass.HAS,
        targetType: exports.Entities.GROUP._type,
    },
    GROUP_HAS_USER: {
        _type: 'gitlab_group_has_user',
        sourceType: exports.Entities.GROUP._type,
        _class: integration_sdk_core_1.RelationshipClass.HAS,
        targetType: exports.Entities.USER._type,
    },
    GROUP_HAS_PROJECT: {
        _type: 'gitlab_group_has_project',
        sourceType: exports.Entities.GROUP._type,
        _class: integration_sdk_core_1.RelationshipClass.HAS,
        targetType: exports.Entities.PROJECT._type,
    },
    PROJECT_HAS_FINDING: {
        _type: 'gitlab_project_has_finding',
        sourceType: exports.Entities.PROJECT._type,
        _class: integration_sdk_core_1.RelationshipClass.HAS,
        targetType: exports.Entities.FINDING._type,
    },
    PROJECT_HAS_PR: {
        _type: 'gitlab_project_has_merge_request',
        sourceType: exports.Entities.PROJECT._type,
        _class: integration_sdk_core_1.RelationshipClass.HAS,
        targetType: exports.Entities.MERGE_REQUEST._type,
    },
    USER_OPENED_PR: {
        _type: 'gitlab_user_opened_merge_request',
        sourceType: exports.Entities.USER._type,
        _class: integration_sdk_core_1.RelationshipClass.OPENED,
        targetType: exports.Entities.MERGE_REQUEST._type,
    },
    USER_APPROVED_PR: {
        _type: 'gitlab_user_approved_merge_request',
        sourceType: exports.Entities.USER._type,
        _class: integration_sdk_core_1.RelationshipClass.APPROVED,
        targetType: exports.Entities.MERGE_REQUEST._type,
    },
    MR_HAS_COMMIT: {
        _type: 'gitlab_merge_request_has_commit',
        sourceType: exports.Entities.MERGE_REQUEST._type,
        _class: integration_sdk_core_1.RelationshipClass.HAS,
        targetType: exports.Entities.COMMIT._type,
    },
    PROJECT_HAS_LABEL: {
        _type: 'gitlab_project_has_label',
        sourceType: exports.Entities.PROJECT._type,
        _class: integration_sdk_core_1.RelationshipClass.HAS,
        targetType: exports.Entities.LABEL._type,
    },
    PROJECT_HAS_BRANCH_RULE: {
        _type: 'gitlab_project_has_branch_rule',
        sourceType: exports.Entities.PROJECT._type,
        _class: integration_sdk_core_1.RelationshipClass.HAS,
        targetType: exports.Entities.BRANCH_RULE._type,
    },
};
//# sourceMappingURL=constants.js.map