import { IntegrationLogger } from '@jupiterone/integration-sdk-core';
import { BranchRule, Commit, Group, GroupMember, Label, MemberInterface, MergeRequest, Project, Vulnerability } from './graphql';
import { IntegrationConfig } from '../config';
import { BaseAPIClient } from '@jupiterone/integration-sdk-http-client';
import { GraphQLError } from './errors';
export type ResourceIteratee<T> = (each: T) => Promise<void> | void;
type VulnerabilityFilters = {
    severities?: string[];
    states?: string[];
    reportTypes?: string[];
};
export declare class GraphQLClient extends BaseAPIClient {
    private readonly personalToken;
    constructor(config: IntegrationConfig, logger: IntegrationLogger);
    private getHandleErrorFn;
    protected getAuthorizationHeaders(): Record<string, string>;
    private gql;
    private iteratePages;
    verifyAuthentication(): Promise<void>;
    fetchTokenOwner(): Promise<import("./graphql").CurrentUser>;
    fetchSystemVersion(): Promise<import("./graphql").Metadata>;
    iterateGroups(iteratee: ResourceIteratee<Group>): Promise<void>;
    iterateProjects(iteratee: ResourceIteratee<Project>): Promise<any>;
    iterateGroupMembers(groupFullPath: string, iteratee: ResourceIteratee<GroupMember>): Promise<void>;
    iterateProjectMembers(projectFullPath: string, iteratee: ResourceIteratee<MemberInterface>): Promise<void>;
    iterateGroupVulnerabilities(groupFullPath: string, vulnerabilityFilters: VulnerabilityFilters, iteratee: ResourceIteratee<Vulnerability>): Promise<void>;
    iterateProjectLabels(projectFullPath: string, iteratee: ResourceIteratee<Label>, handleError?: (err: GraphQLError) => void): Promise<void>;
    iterateProjectMergeRequests(projectFullPath: string, updatedAfter: string, iteratee: ResourceIteratee<MergeRequest>): Promise<void>;
    iterateMergeRequestCommits(mergeRequestId: string, iteratee: ResourceIteratee<Commit>): Promise<void>;
    iterateProjectBranchRules(projectFullPath: string, iteratee: ResourceIteratee<BranchRule>): Promise<void>;
}
export {};
//# sourceMappingURL=GraphQLClient.d.ts.map