"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ProjectBranchRulesQuery = exports.MergeRequestCommitsQuery = exports.ProjectMergeRequestsQuery = exports.ProjectLabelsQuery = exports.GroupVulnerabilitiesQuery = exports.ProjectMembersQuery = exports.GroupMembersQuery = exports.ProjectsQuery = exports.GroupsQuery = exports.SystemVersionQuery = exports.TokenOwnerQuery = void 0;
exports.TokenOwnerQuery = `
  query {
    currentUser {
      id
      name
    }
  }
`;
exports.SystemVersionQuery = `
query {
  metadata {
    version
    revision
    enterprise
  }
}
`;
exports.GroupsQuery = `
query getGroups($first: Int!, $cursor: String) {
  currentUser {
    groups(first: $first, after: $cursor) {
      nodes {
        id
        name
        parent {
          id
        }
        createdAt
        path
        description
        visibility
        shareWithGroupLock
        requireTwoFactorAuthentication
        twoFactorGracePeriod
        projectCreationLevel
        autoDevopsEnabled
        subgroupCreationLevel
        emailsDisabled
        mentionsDisabled
        lfsEnabled
        webUrl
        requestAccessEnabled
        fullName
        fullPath
        groupMembersCount
      }
      pageInfo {
        endCursor
        hasNextPage
      }
    }
  }
}
`;
exports.ProjectsQuery = `
query getProjects($first: Int!, $cursor: String) {
  projects(membership: true, first: $first, after: $cursor) {
    nodes {
      id
      name
      createdAt
      description
      webUrl
      visibility
      issuesEnabled
      mergeRequestsEnabled
      jobsEnabled
      wikiEnabled
      snippetsEnabled
      containerRegistryEnabled
      archived
      sharedRunnersEnabled
      publicJobs
      allowMergeOnSkippedPipeline
      onlyAllowMergeIfPipelineSucceeds
      onlyAllowMergeIfAllDiscussionsAreResolved
      removeSourceBranchAfterMerge
      requestAccessEnabled
      autocloseReferencedIssues
      topics
      fullPath
      group {
        id
      }
    }
    pageInfo {
      endCursor
      hasNextPage
    }
  }
}
`;
exports.GroupMembersQuery = `
query getGroupMembers($groupFullPath: ID!, $first: Int!, $cursor: String) {
  group(fullPath: $groupFullPath) {
    groupMembers(first: $first, after: $cursor) {
      nodes {
        accessLevel {
          integerValue
          stringValue
        }
        id
        user {
          id
          name
          createdAt
          webUrl
          username
          state
          publicEmail
        }
        userPermissions {
          createCustomEmoji
          createProjects
          readGroup
          removeGroup
          viewEditPage
        }
        expiresAt
        createdAt
        updatedAt
      }
      pageInfo {
        endCursor
        hasNextPage
      }
    }
  }
}
`;
exports.ProjectMembersQuery = `
query getProjectMembers($projectFullPath: ID!, $first: Int!, $cursor: String) {
  project(fullPath: $projectFullPath) {
    projectMembers(first: $first, after: $cursor) {
      nodes {
        accessLevel {
          integerValue
          stringValue
        }
        createdAt
        expiresAt
        id
        updatedAt
        user {
          id
          name
          createdAt
          webUrl
          username
          state
          publicEmail
        }
      }
      pageInfo {
        endCursor
        hasNextPage
      }
    }
  }
}
`;
exports.GroupVulnerabilitiesQuery = `
query getGroupVulnerabilities($groupFullPath: ID!, $severities: [VulnerabilitySeverity!], $states: [VulnerabilityState!], $reportTypes: [VulnerabilityReportType!], $first: Int!, $cursor: String) {
  group(fullPath: $groupFullPath) {
    vulnerabilities(severity: $severities, state: $states, reportType: $reportTypes, first: $first, after: $cursor) {
      nodes {
        project {
          id
          fullPath
        }
        uuid
        reportType
        severity
        state
        title
        scanner {
          externalId
          name
          vendor
        }
        identifiers {
          externalId
        }
        falsePositive
        dismissalReason
        links {
          url
        }
        solution
        vulnerabilityPath
      }
      pageInfo {
        endCursor
        hasNextPage
      }
    }
  }
}
`;
exports.ProjectLabelsQuery = `
query getProjectLabels($projectFullPath: ID!, $first: Int!, $cursor: String) {
  project(fullPath: $projectFullPath) {
    labels(first: $first, after: $cursor) {
      nodes {
        id
        title
        color
        textColor
        description
        lockOnMerge
      }
      pageInfo {
        endCursor
        hasNextPage
      }
    }
  }
}
`;
exports.ProjectMergeRequestsQuery = `
query getProjectMergeRequests($projectFullPath: ID!, $updatedAfter: Time!, $first: Int!, $cursor: String) {
  project(fullPath: $projectFullPath) {
    mergeRequests(updatedAfter: $updatedAfter, first: $first, after: $cursor) {
      nodes {
        id
        iid
        projectId
        title
        state
        sourceBranch
        targetBranch
        createdAt
        updatedAt
        author {
          id
          name
          username
        }
        webUrl
        mergeWhenPipelineSucceeds
        shouldRemoveSourceBranch
        forceRemoveSourceBranch
        allowCollaboration
        squash
        approved
        approvedBy {
          nodes {
            id
            name
            username
          }
        }
        mergedAt
        diffHeadSha
        mergeCommitSha
      }
      pageInfo {
        endCursor
        hasNextPage
      }
    }
  }
}
`;
exports.MergeRequestCommitsQuery = `
query getMergeRequestCommits($mergeRequestId: MergeRequestID!, $first: Int!, $cursor: String) {
  mergeRequest(id: $mergeRequestId) {
    commits(first: $first, after: $cursor) {
      nodes {
        id
        shortId
        title
        committedDate
        webUrl
        message
        authoredDate
        committerName
        committerEmail
        authorName
        authorEmail
      }
      pageInfo {
        endCursor
        hasNextPage
      }
    }
  }
}
`;
exports.ProjectBranchRulesQuery = `
query getProjectBranchRules($projectFullPath: ID!, $first: Int!, $cursor: String) {
  project(fullPath: $projectFullPath) {
    branchRules(first: $first, after: $cursor) {
      nodes {
        id
        name
        isDefault
        isProtected
        createdAt
        updatedAt
        matchingBranchesCount
        branchProtection {
          allowForcePush
          codeOwnerApprovalRequired
          mergeAccessLevels {
            nodes {
              accessLevelDescription
              group {
                id
              }
              user {
                id
              }
            }
          }
          pushAccessLevels {
            nodes {
              accessLevelDescription
              group {
                id
              }
              user {
                id
              }
            }
          }
        }
      }
      pageInfo {
        endCursor
        hasNextPage
      }
    }
  }
}
`;
//# sourceMappingURL=graphqlQueries.js.map