"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.branchRulesSteps = void 0;
exports.fetchBranchRules = fetchBranchRules;
const integration_sdk_core_1 = require("@jupiterone/integration-sdk-core");
const constants_1 = require("../../constants");
const provider_1 = require("../../provider");
const converter_1 = require("./converter");
async function fetchBranchRules({ instance, jobState, logger, }) {
    const client = (0, provider_1.createAPIClient)(instance.config, logger);
    await jobState.iterateEntities(constants_1.Entities.PROJECT, async (projectEntity) => {
        const project = (0, integration_sdk_core_1.getRawData)(projectEntity);
        if (!project) {
            throw new integration_sdk_core_1.IntegrationError({
                code: 'RAW_DATA_MISSING',
                message: `Could not find Project entity with _key ${projectEntity._key}`,
            });
        }
        await client.iterateProjectBranchRules(project.fullPath, async (branchRule) => {
            const branchRuleEntity = (0, converter_1.createBranchRuleEntity)(branchRule);
            await jobState.addEntity(branchRuleEntity);
            await jobState.addRelationship((0, integration_sdk_core_1.createDirectRelationship)({
                _class: constants_1.Relationships.PROJECT_HAS_BRANCH_RULE._class,
                from: projectEntity,
                to: branchRuleEntity,
            }));
        });
    });
}
exports.branchRulesSteps = [
    {
        id: constants_1.Steps.BRANCH_RULES,
        name: 'Fetch Branch Rules',
        entities: [constants_1.Entities.BRANCH_RULE],
        relationships: [constants_1.Relationships.PROJECT_HAS_BRANCH_RULE],
        dependsOn: [constants_1.Steps.PROJECTS],
        ingestionSourceId: constants_1.IngestionSources.BRANCH_RULES,
        executionHandler: fetchBranchRules,
    },
];
//# sourceMappingURL=index.js.map