"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createCommitIdentifier = createCommitIdentifier;
exports.createMergeRequestCommitEntity = createMergeRequestCommitEntity;
const integration_sdk_core_1 = require("@jupiterone/integration-sdk-core");
const entity_definitions_1 = require("../../entity-definitions");
const COMMIT_ID_PREFIX = 'gitlab-commit';
function createCommitIdentifier(id) {
    const uuid = id.split('/').pop();
    return `${COMMIT_ID_PREFIX}:${uuid}`;
}
function createMergeRequestCommitEntity(commit, sourceBranch) {
    const key = createCommitIdentifier(commit.id);
    return (0, integration_sdk_core_1.createIntegrationEntity)({
        entityData: {
            source: commit,
            assign: (0, entity_definitions_1.createGitlabCommit)({
                _key: key,
                id: commit.id,
                shortId: commit.shortId,
                title: commit.title ?? undefined,
                name: commit.title ?? commit.shortId,
                merge: false,
                versionBump: false,
                webLink: commit.webUrl,
                message: commit.message ?? '',
                authoredOn: (0, integration_sdk_core_1.parseTimePropertyValue)(commit.authoredDate),
                committedOn: (0, integration_sdk_core_1.parseTimePropertyValue)(commit.committedDate),
                commitWebLink: commit.webUrl,
                committerName: commit.committerName ?? undefined,
                committerEmail: commit.committerEmail ?? undefined,
                authorName: commit.authorName ?? undefined,
                authorEmail: commit.authorEmail ?? undefined,
                branch: sourceBranch,
                /** @deprecated identical to `committedOn` property */
                createdOn: (0, integration_sdk_core_1.parseTimePropertyValue)(commit.committedDate),
            }),
        },
    });
}
//# sourceMappingURL=converter.js.map