"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.commitSteps = void 0;
exports.fetchCommits = fetchCommits;
const integration_sdk_core_1 = require("@jupiterone/integration-sdk-core");
const constants_1 = require("../../constants");
const provider_1 = require("../../provider");
const converter_1 = require("./converter");
async function fetchCommits({ logger, instance, jobState, }) {
    const client = (0, provider_1.createAPIClient)(instance.config, logger);
    await jobState.iterateEntities(constants_1.Entities.MERGE_REQUEST, async (mergeRequestEntity) => {
        const mergeRequest = (0, integration_sdk_core_1.getRawData)(mergeRequestEntity);
        if (!mergeRequest) {
            throw new integration_sdk_core_1.IntegrationError({
                code: 'RAW_DATA_MISSING',
                message: `Could not find MergeRequest entity with _key ${mergeRequestEntity._key}`,
            });
        }
        try {
            await client.iterateMergeRequestCommits(mergeRequest.id, async (mergeRequestCommit) => {
                const commitEntity = (0, converter_1.createMergeRequestCommitEntity)(mergeRequestCommit, mergeRequest.sourceBranch);
                if (!jobState.hasKey(commitEntity._key)) {
                    await jobState.addEntity(commitEntity);
                }
                const relationship = (0, integration_sdk_core_1.createDirectRelationship)({
                    _class: constants_1.Relationships.MR_HAS_COMMIT._class,
                    from: mergeRequestEntity,
                    to: commitEntity,
                });
                if (!jobState.hasKey(relationship._key)) {
                    await jobState.addRelationship(relationship);
                }
            });
        }
        catch (err) {
            const logDetail = {
                err,
                projectId: mergeRequestEntity.projectId,
            };
            if (err instanceof integration_sdk_core_1.IntegrationProviderAuthorizationError) {
                logger.warn(logDetail, 'Unauthorized to fetch merge request commits for project');
            }
            else {
                throw err;
            }
        }
    });
}
exports.commitSteps = [
    {
        id: constants_1.Steps.COMMITS,
        name: 'Fetch MR commits',
        entities: [constants_1.Entities.COMMIT],
        relationships: [constants_1.Relationships.MR_HAS_COMMIT],
        dependsOn: [constants_1.Steps.MERGE_REQUESTS],
        ingestionSourceId: constants_1.IngestionSources.COMMITS,
        executionHandler: fetchCommits,
    },
];
//# sourceMappingURL=index.js.map