"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createFindingIdentifier = createFindingIdentifier;
exports.createVulnerabilityFindingEntity = createVulnerabilityFindingEntity;
const integration_sdk_core_1 = require("@jupiterone/integration-sdk-core");
const entity_definitions_1 = require("../../entity-definitions");
function getNumericSeverity(severity) {
    if (!severity) {
        return 0;
    }
    else if (/critical/i.test(severity)) {
        return 10;
    }
    else if (/high/i.test(severity)) {
        return 7;
    }
    else if (/medium/i.test(severity)) {
        return 5;
    }
    else if (/low/i.test(severity)) {
        return 2;
    }
    else if (/info/i.test(severity)) {
        return 1;
    }
    else {
        return 0;
    }
}
const FINDING_ID_PREFIX = 'gitlab-finding';
function createFindingIdentifier(id) {
    return `${FINDING_ID_PREFIX}:${id}`;
}
function createVulnerabilityFindingEntity(finding, projectFullPath) {
    return (0, integration_sdk_core_1.createIntegrationEntity)({
        entityData: {
            source: finding,
            assign: (0, entity_definitions_1.createGitlabFinding)({
                _key: createFindingIdentifier(finding.uuid),
                // START: finding data model required fields
                category: finding.reportType,
                severity: finding.severity,
                numericSeverity: getNumericSeverity(finding.severity),
                open: finding.state === 'DETECTED',
                // END: finding data model required fields
                uuid: finding.uuid ?? undefined,
                reportType: finding.reportType ?? undefined,
                name: finding.title ?? finding.uuid,
                'scanner.externalId': finding.scanner?.externalId ?? undefined,
                'scanner.name': finding.scanner?.name ?? undefined,
                'scanner.vendor': finding.scanner?.vendor ?? undefined,
                identifiers: finding.identifiers?.map((identifier) => identifier.externalId),
                falsePositive: finding.falsePositive ?? undefined,
                dismissalReason: finding.dismissalReason ?? undefined,
                description: finding.description ?? undefined,
                links: finding.links?.map((link) => link.url),
                solution: finding.solution ?? undefined,
                state: finding.state ?? undefined,
                vulnerabilityPath: finding.vulnerabilityPath ?? undefined,
                /** @deprecated projectFingerprint is the same as uuid */
                projectFingerprint: finding.uuid ?? undefined,
                /** @deprecated dismissal_feedback is renamed to dismissalReason in graphql api */
                dismissalFeedback: finding.dismissalReason ?? undefined,
                /** @deprecated create_vulnerability_feedback_issue_path is removed in graphql api response */
                createVulnerabilityFeedbackIssuePath: `/${projectFullPath}/-/vulnerability_feedback`,
                /** @deprecated create_vulnerability_feedback_merge_request_path is removed in graphql api response */
                createVulnerabilityFeedbackMergeRequestPath: `/${projectFullPath}/-/vulnerability_feedback`,
                /** @deprecated create_vulnerability_feedback_dismissal_path is removed in graphql api response */
                createVulnerabilityFeedbackDismissalPath: `/${projectFullPath}/-/vulnerability_feedback`,
            }),
        },
    });
}
//# sourceMappingURL=converter.js.map