"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.findingSteps = void 0;
exports.fetchVulnerabilityFindings = fetchVulnerabilityFindings;
const integration_sdk_core_1 = require("@jupiterone/integration-sdk-core");
const constants_1 = require("../../constants");
const provider_1 = require("../../provider");
const converter_1 = require("./converter");
const converter_2 = require("../projects/converter");
const getNumericalId_1 = require("../../util/getNumericalId");
async function fetchVulnerabilityFindings({ instance, jobState, logger, }) {
    const client = (0, provider_1.createAPIClient)(instance.config, logger);
    const { vulnerabilitySeverities, vulnerabilityStates, vulnerabilityReportTypes, } = instance.config;
    const filters = {
        severities: vulnerabilitySeverities,
        states: vulnerabilityStates,
        reportTypes: vulnerabilityReportTypes,
    };
    const groupVulnsFailed = [];
    await jobState.iterateEntities(constants_1.Entities.GROUP, async (groupEntity) => {
        try {
            await client.iterateGroupVulnerabilities(groupEntity.fullPath, filters, async (finding) => {
                const project = finding.project;
                if (!project) {
                    return;
                }
                const projectKey = (0, converter_2.createProjectEntityIdentifier)((0, getNumericalId_1.getNumericalId)(project.id));
                if (!jobState.hasKey(projectKey)) {
                    return;
                }
                const findingEntity = (0, converter_1.createVulnerabilityFindingEntity)(finding, project.fullPath);
                if (!jobState.hasKey(findingEntity._key)) {
                    await jobState.addEntity(findingEntity);
                }
                const relationship = (0, integration_sdk_core_1.createDirectRelationship)({
                    _class: constants_1.Relationships.PROJECT_HAS_FINDING._class,
                    fromKey: projectKey,
                    fromType: constants_1.Entities.PROJECT._type,
                    toKey: findingEntity._key,
                    toType: constants_1.Entities.FINDING._type,
                });
                if (!jobState.hasKey(relationship._key)) {
                    await jobState.addRelationship(relationship);
                }
            });
        }
        catch (err) {
            if (err instanceof integration_sdk_core_1.IntegrationProviderAuthorizationError) {
                groupVulnsFailed.push(groupEntity.fullPath);
                logger.warn({
                    err,
                    groupId: groupEntity.id,
                    groupFullPath: groupEntity.fullPath,
                }, `User does not have permission to fetch findings for group ${groupEntity.id}`);
            }
            else {
                throw err;
            }
        }
    });
    if (groupVulnsFailed.length) {
        logger.publishWarnEvent({
            name: integration_sdk_core_1.IntegrationWarnEventName.MissingPermission,
            description: `Could not fetch vulnerability findings for the following groups: ${groupVulnsFailed.join(', ')}. Please ensure the user has access to these groups vulnerability findings.`,
        });
    }
}
exports.findingSteps = [
    {
        id: constants_1.Steps.FINDINGS,
        name: 'Fetch Vulnerability Findings',
        entities: [constants_1.Entities.FINDING],
        relationships: [constants_1.Relationships.PROJECT_HAS_FINDING],
        dependsOn: [constants_1.Steps.PROJECTS],
        ingestionSourceId: constants_1.IngestionSources.FINDINGS,
        executionHandler: fetchVulnerabilityFindings,
    },
];
//# sourceMappingURL=index.js.map