"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createGroupEntityIdentifier = createGroupEntityIdentifier;
exports.createGroupEntity = createGroupEntity;
const integration_sdk_core_1 = require("@jupiterone/integration-sdk-core");
const getNumericalId_1 = require("../../util/getNumericalId");
const entity_definitions_1 = require("../../entity-definitions");
const GROUP_ID_PREFIX = 'gitlab-group';
function createGroupEntityIdentifier(id) {
    return `${GROUP_ID_PREFIX}:${id}`;
}
function createGroupEntity(group) {
    const id = (0, getNumericalId_1.getNumericalId)(group.id);
    const key = createGroupEntityIdentifier(id);
    return (0, integration_sdk_core_1.createIntegrationEntity)({
        entityData: {
            source: group,
            assign: (0, entity_definitions_1.createGitlabGroup)({
                _key: key,
                id: String(id),
                parentGroupId: group.parent?.id && group.parent.id,
                name: group.name,
                createdOn: (0, integration_sdk_core_1.parseTimePropertyValue)(group.createdAt),
                path: group.path,
                description: group.description ?? undefined,
                visibility: group.visibility ?? undefined,
                shareWithGroupLock: group.shareWithGroupLock ?? undefined,
                requireTwoFactorAuthentication: group.requireTwoFactorAuthentication ?? undefined,
                twoFactorGracePeriod: group.twoFactorGracePeriod ?? undefined,
                projectCreationLevel: group.projectCreationLevel ?? undefined,
                autoDevopsEnabled: group.autoDevopsEnabled ?? undefined,
                subgroupCreationLevel: group.subgroupCreationLevel ?? undefined,
                emailsDisabled: group.emailsDisabled ?? undefined,
                mentionsDisabled: group.mentionsDisabled ?? undefined,
                lfsEnabled: group.lfsEnabled ?? undefined,
                webUrl: group.webUrl,
                requestAccessEnabled: group.requestAccessEnabled ?? undefined,
                fullName: group.fullName,
                fullPath: group.fullPath,
            }),
        },
    });
}
//# sourceMappingURL=converter.js.map