"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.groupSteps = void 0;
const integration_sdk_core_1 = require("@jupiterone/integration-sdk-core");
const provider_1 = require("../../provider");
const constants_1 = require("../../constants");
const converter_1 = require("./converter");
const getNumericalId_1 = require("../../util/getNumericalId");
async function fetchGroups({ instance, jobState, logger, }) {
    const client = (0, provider_1.createAPIClient)(instance.config, logger);
    const accountEntity = await jobState.getData(constants_1.ACCOUNT_ENTITY);
    if (!accountEntity) {
        throw new integration_sdk_core_1.IntegrationError({
            code: 'ACCOUNT_ENTITY_NOT_FOUND',
            message: 'Account entity not found',
        });
    }
    await client.iterateGroups(async (group) => {
        const groupEntity = (0, converter_1.createGroupEntity)(group);
        await jobState.addEntity(groupEntity);
        await jobState.addRelationship((0, integration_sdk_core_1.createDirectRelationship)({
            _class: constants_1.Relationships.ACCOUNT_HAS_GROUP._class,
            from: accountEntity,
            to: groupEntity,
        }));
    });
    // Build Group -HAS-> Subgroup relationships
    await jobState.iterateEntities(constants_1.Entities.GROUP, async (groupEntity) => {
        const parentGroupId = groupEntity.parentGroupId;
        if (!parentGroupId) {
            return;
        }
        const parentGroupKey = (0, converter_1.createGroupEntityIdentifier)((0, getNumericalId_1.getNumericalId)(parentGroupId));
        if (!jobState.hasKey(parentGroupKey)) {
            return;
        }
        await jobState.addRelationship((0, integration_sdk_core_1.createDirectRelationship)({
            _class: constants_1.Relationships.GROUP_HAS_SUBGROUP._class,
            fromType: constants_1.Entities.GROUP._type,
            fromKey: parentGroupKey,
            toType: constants_1.Entities.GROUP._type,
            toKey: groupEntity._key,
        }));
    });
}
exports.groupSteps = [
    {
        id: constants_1.Steps.GROUPS,
        name: 'Fetch groups',
        entities: [constants_1.Entities.GROUP],
        relationships: [
            constants_1.Relationships.ACCOUNT_HAS_GROUP,
            constants_1.Relationships.GROUP_HAS_SUBGROUP,
        ],
        dependsOn: [constants_1.Steps.ACCOUNTS],
        ingestionSourceId: constants_1.IngestionSources.GROUPS,
        executionHandler: fetchGroups,
    },
];
//# sourceMappingURL=index.js.map