"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createMergeRequestEntityIdentifier = createMergeRequestEntityIdentifier;
exports.createMergeRequestEntity = createMergeRequestEntity;
const integration_sdk_core_1 = require("@jupiterone/integration-sdk-core");
const mergeRequest_1 = require("../../util/mergeRequest");
const getNumericalId_1 = require("../../util/getNumericalId");
const entity_definitions_1 = require("../../entity-definitions");
const MERGE_REQUEST_ID_PREFIX = 'gitlab-merge-request';
function createMergeRequestEntityIdentifier(id) {
    return `${MERGE_REQUEST_ID_PREFIX}:${id}`;
}
function createMergeRequestEntity(projectName, mergeRequest) {
    const id = (0, getNumericalId_1.getNumericalId)(mergeRequest.id);
    return (0, integration_sdk_core_1.createIntegrationEntity)({
        entityData: {
            source: mergeRequest,
            assign: (0, entity_definitions_1.createGitlabMergeRequest)({
                _key: createMergeRequestEntityIdentifier(id),
                id: String(id),
                iid: mergeRequest.iid,
                projectId: mergeRequest.projectId,
                name: mergeRequest.title,
                displayName: mergeRequest.title,
                title: mergeRequest.title,
                state: mergeRequest.state,
                source: mergeRequest.sourceBranch,
                target: mergeRequest.targetBranch,
                repository: projectName,
                createdOn: (0, integration_sdk_core_1.parseTimePropertyValue)(mergeRequest.createdAt),
                updatedOn: (0, integration_sdk_core_1.parseTimePropertyValue)(mergeRequest.updatedAt),
                authorId: mergeRequest.author?.id,
                authorName: mergeRequest.author?.name,
                authorLogin: mergeRequest.author?.username,
                webLink: mergeRequest.webUrl ?? undefined,
                mergeWhenPipelineSucceeds: mergeRequest.mergeWhenPipelineSucceeds ?? undefined,
                shouldRemoveSourceBranch: !!mergeRequest.shouldRemoveSourceBranch,
                forceRemoveSourceBranch: mergeRequest.forceRemoveSourceBranch ?? undefined,
                allowCollaboration: mergeRequest.allowCollaboration ?? undefined,
                squash: mergeRequest.squash,
                approved: mergeRequest.approved,
                approvers: mergeRequest?.approvedBy?.nodes
                    ?.map((approver) => approver?.name)
                    .filter(Boolean) ?? [],
                approverIds: mergeRequest?.approvedBy?.nodes
                    ?.map((approver) => approver?.id)
                    .filter(Boolean) ?? [],
                approverLogins: mergeRequest?.approvedBy?.nodes
                    ?.map((approver) => approver?.username)
                    .filter(Boolean) ?? [],
                mergedOn: (0, integration_sdk_core_1.parseTimePropertyValue)(mergeRequest.mergedAt),
                sha: mergeRequest.diffHeadSha ?? undefined,
                mergeCommitSha: mergeRequest.mergeCommitSha ?? undefined,
                commitWebLink: (0, mergeRequest_1.getCommitWebLinkFromMergeRequest)(mergeRequest),
                // NOTE: if it's not accurate, we'll ask the customer to change the query
                closedOn: mergeRequest.state === 'closed'
                    ? (0, integration_sdk_core_1.parseTimePropertyValue)(mergeRequest.updatedAt)
                    : undefined,
            }),
        },
    });
}
//# sourceMappingURL=converter.js.map