"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createProjectEntityIdentifier = createProjectEntityIdentifier;
exports.createProjectEntity = createProjectEntity;
const integration_sdk_core_1 = require("@jupiterone/integration-sdk-core");
const getNumericalId_1 = require("../../util/getNumericalId");
const entity_definitions_1 = require("../../entity-definitions");
const PROJECT_ID_PREFIX = 'gitlab-project';
function createProjectEntityIdentifier(id) {
    return `${PROJECT_ID_PREFIX}:${id}`;
}
function createProjectEntity(project) {
    const id = (0, getNumericalId_1.getNumericalId)(project.id);
    return (0, integration_sdk_core_1.createIntegrationEntity)({
        entityData: {
            source: project,
            assign: (0, entity_definitions_1.createGitlabProject)({
                _key: createProjectEntityIdentifier(id),
                id: String(id),
                name: project.name,
                displayName: project.name,
                createdOn: (0, integration_sdk_core_1.parseTimePropertyValue)(project.createdAt),
                description: project.description ?? undefined,
                webLink: project.webUrl ?? undefined,
                visibility: project.visibility ?? undefined,
                public: project.visibility !== 'private',
                issuesEnabled: project.issuesEnabled ?? undefined,
                mergeRequestsEnabled: project.mergeRequestsEnabled ?? undefined,
                jobsEnabled: project.jobsEnabled ?? undefined,
                wikiEnabled: project.wikiEnabled ?? undefined,
                snippetsEnabled: project.snippetsEnabled ?? undefined,
                containerRegistryEnabled: project.containerRegistryEnabled ?? undefined,
                archived: project.archived ?? undefined,
                sharedRunnersEnabled: project.sharedRunnersEnabled ?? undefined,
                publicJobs: project.publicJobs ?? undefined,
                allowMergeOnSkippedPipeline: !!project.allowMergeOnSkippedPipeline,
                onlyAllowMergeIfPipelineSucceeds: project.onlyAllowMergeIfPipelineSucceeds ?? undefined,
                onlyAllowMergeIfAllDiscussionsAreResolved: project.onlyAllowMergeIfAllDiscussionsAreResolved ?? undefined,
                removeSourceBranchAfterMerge: project.removeSourceBranchAfterMerge ?? undefined,
                requestAccessEnabled: project.requestAccessEnabled ?? undefined,
                autocloseReferencedIssues: project.autocloseReferencedIssues ?? undefined,
                topics: project.topics ?? [],
                fullName: project.fullPath,
            }),
        },
    });
}
//# sourceMappingURL=converter.js.map