"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.projectSteps = void 0;
exports.fetchProjects = fetchProjects;
const integration_sdk_core_1 = require("@jupiterone/integration-sdk-core");
const constants_1 = require("../../constants");
const provider_1 = require("../../provider");
const converter_1 = require("../groups/converter");
const converter_2 = require("./converter");
const getNumericalId_1 = require("../../util/getNumericalId");
async function fetchProjects({ instance, jobState, logger, }) {
    const client = (0, provider_1.createAPIClient)(instance.config, logger);
    const accountEntity = await jobState.getData(constants_1.ACCOUNT_ENTITY);
    if (!accountEntity) {
        throw new integration_sdk_core_1.IntegrationError({
            code: 'ACCOUNT_ENTITY_NOT_FOUND',
            message: 'Account entity not found',
        });
    }
    await client.iterateProjects(async (project) => {
        const projectEntity = (0, converter_2.createProjectEntity)(project);
        if (!jobState.hasKey(projectEntity._key)) {
            await jobState.addEntity(projectEntity);
        }
        await jobState.addRelationship((0, integration_sdk_core_1.createDirectRelationship)({
            _class: constants_1.Relationships.ACCOUNT_HAS_PROJECT._class,
            from: accountEntity,
            to: projectEntity,
        }));
        const groupKey = project.group?.id &&
            (0, converter_1.createGroupEntityIdentifier)((0, getNumericalId_1.getNumericalId)(project.group.id));
        if (!groupKey || !jobState.hasKey(groupKey)) {
            return;
        }
        await jobState.addRelationship((0, integration_sdk_core_1.createDirectRelationship)({
            _class: constants_1.Relationships.GROUP_HAS_PROJECT._class,
            fromKey: groupKey,
            fromType: constants_1.Relationships.GROUP_HAS_PROJECT.sourceType,
            toKey: projectEntity._key,
            toType: constants_1.Relationships.GROUP_HAS_PROJECT.targetType,
        }));
    });
}
exports.projectSteps = [
    {
        id: constants_1.Steps.PROJECTS,
        name: 'Fetch projects',
        entities: [constants_1.Entities.PROJECT],
        relationships: [
            constants_1.Relationships.ACCOUNT_HAS_PROJECT,
            constants_1.Relationships.GROUP_HAS_PROJECT,
        ],
        dependsOn: [constants_1.Steps.ACCOUNTS, constants_1.Steps.GROUPS],
        ingestionSourceId: constants_1.IngestionSources.PROJECTS,
        executionHandler: fetchProjects,
    },
];
//# sourceMappingURL=index.js.map