"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createUserEntityIdentifier = createUserEntityIdentifier;
exports.createUserEntity = createUserEntity;
exports.createGroupHasUserRelationship = createGroupHasUserRelationship;
exports.createProjectHasUserRelationship = createProjectHasUserRelationship;
const integration_sdk_core_1 = require("@jupiterone/integration-sdk-core");
const constants_1 = require("../../constants");
const getNumericalId_1 = require("../../util/getNumericalId");
const entity_definitions_1 = require("../../entity-definitions");
const USER_ID_PREFIX = 'gitlab-user';
function createUserEntityIdentifier(id) {
    return `${USER_ID_PREFIX}:${id}`;
}
function createUserEntity(user, details) {
    const id = (0, getNumericalId_1.getNumericalId)(user.id);
    return (0, integration_sdk_core_1.createIntegrationEntity)({
        entityData: {
            source: user,
            assign: (0, entity_definitions_1.createGitlabUser)({
                _key: createUserEntityIdentifier(id),
                id: String(id),
                name: user.name,
                createdOn: (0, integration_sdk_core_1.parseTimePropertyValue)(user.createdAt),
                webLink: user.webUrl,
                username: user.username,
                state: user.state,
                email: user.publicEmail ?? undefined,
                publicEmail: user.publicEmail ?? undefined,
                active: user.state === 'active',
                // For administrators (self-managed instance)
                // These fields are not in graphql response, so we need to fetch them from the REST API.
                isAdmin: details?.is_admin,
                canCreateGroup: details?.can_create_group,
                canCreateProject: details?.can_create_project,
                twoFactorEnabled: details?.two_factor_enabled, // in the group
                external: details?.external,
                privateProfile: details?.private_profile,
                trial: details?.trial,
            }),
        },
    });
}
function createGroupHasUserRelationship({ groupEntityKey, userEntityKey, edge, }) {
    return (0, integration_sdk_core_1.createDirectRelationship)({
        _class: constants_1.Relationships.GROUP_HAS_USER._class,
        fromKey: groupEntityKey,
        fromType: constants_1.Entities.GROUP._type,
        toKey: userEntityKey,
        toType: constants_1.Entities.USER._type,
        properties: {
            accessLevel: edge.accessLevel?.stringValue,
            'permissions.createCustomEmoji': edge.userPermissions?.createCustomEmoji,
            'permissions.createProjects': edge.userPermissions?.createProjects,
            'permissions.readGroup': edge.userPermissions?.readGroup,
            'permissions.removeGroup': edge.userPermissions?.removeGroup,
            'permissions.viewEditPage': edge.userPermissions?.viewEditPage,
            expiresAt: (0, integration_sdk_core_1.parseTimePropertyValue)(edge.expiresAt),
            createdAt: (0, integration_sdk_core_1.parseTimePropertyValue)(edge.createdAt),
            updatedAt: (0, integration_sdk_core_1.parseTimePropertyValue)(edge.updatedAt),
        },
    });
}
function createProjectHasUserRelationship({ projectEntityKey, userEntityKey, edge, }) {
    return (0, integration_sdk_core_1.createDirectRelationship)({
        _class: constants_1.Relationships.PROJECT_HAS_USER._class,
        fromKey: projectEntityKey,
        fromType: constants_1.Entities.PROJECT._type,
        toKey: userEntityKey,
        toType: constants_1.Entities.USER._type,
        properties: {
            accessLevel: edge.accessLevel?.stringValue,
            createdAt: (0, integration_sdk_core_1.parseTimePropertyValue)(edge.createdAt),
            updatedAt: (0, integration_sdk_core_1.parseTimePropertyValue)(edge.updatedAt),
            expiresAt: (0, integration_sdk_core_1.parseTimePropertyValue)(edge.expiresAt),
        },
    });
}
//# sourceMappingURL=converter.js.map