export declare const TokenOwnerQuery = "\n  query {\n    currentUser {\n      id\n      name\n    }\n  }\n";
export declare const SystemVersionQuery = "\nquery {\n  metadata {\n    version\n    revision\n    enterprise\n  }\n}\n";
export declare const GroupsQuery = "\nquery getGroups($first: Int!, $cursor: String) {\n  currentUser {\n    groups(first: $first, after: $cursor) {\n      nodes {\n        id\n        name\n        parent {\n          id\n        }\n        createdAt\n        path\n        description\n        visibility\n        shareWithGroupLock\n        requireTwoFactorAuthentication\n        twoFactorGracePeriod\n        projectCreationLevel\n        autoDevopsEnabled\n        subgroupCreationLevel\n        emailsDisabled\n        mentionsDisabled\n        lfsEnabled\n        webUrl\n        requestAccessEnabled\n        fullName\n        fullPath\n        groupMembersCount\n      }\n      pageInfo {\n        endCursor\n        hasNextPage\n      }\n    }\n  }\n}\n";
export declare const ProjectsQuery = "\nquery getProjects($first: Int!, $cursor: String) {\n  projects(membership: true, first: $first, after: $cursor) {\n    nodes {\n      id\n      name\n      createdAt\n      description\n      webUrl\n      visibility\n      issuesEnabled\n      mergeRequestsEnabled\n      jobsEnabled\n      wikiEnabled\n      snippetsEnabled\n      containerRegistryEnabled\n      archived\n      sharedRunnersEnabled\n      publicJobs\n      allowMergeOnSkippedPipeline\n      onlyAllowMergeIfPipelineSucceeds\n      onlyAllowMergeIfAllDiscussionsAreResolved\n      removeSourceBranchAfterMerge\n      requestAccessEnabled\n      autocloseReferencedIssues\n      topics\n      fullPath\n      group {\n        id\n      }\n    }\n    pageInfo {\n      endCursor\n      hasNextPage\n    }\n  }\n}\n";
export declare const GroupMembersQuery = "\nquery getGroupMembers($groupFullPath: ID!, $first: Int!, $cursor: String) {\n  group(fullPath: $groupFullPath) {\n    groupMembers(first: $first, after: $cursor) {\n      nodes {\n        accessLevel {\n          integerValue\n          stringValue\n        }\n        id\n        user {\n          id\n          name\n          createdAt\n          webUrl\n          username\n          state\n          publicEmail\n        }\n        userPermissions {\n          createCustomEmoji\n          createProjects\n          readGroup\n          removeGroup\n          viewEditPage\n        }\n        expiresAt\n        createdAt\n        updatedAt\n      }\n      pageInfo {\n        endCursor\n        hasNextPage\n      }\n    }\n  }\n}\n";
export declare const ProjectMembersQuery = "\nquery getProjectMembers($projectFullPath: ID!, $first: Int!, $cursor: String) {\n  project(fullPath: $projectFullPath) {\n    projectMembers(first: $first, after: $cursor) {\n      nodes {\n        accessLevel {\n          integerValue\n          stringValue\n        }\n        createdAt\n        expiresAt\n        id\n        updatedAt\n        user {\n          id\n          name\n          createdAt\n          webUrl\n          username\n          state\n          publicEmail\n        }\n      }\n      pageInfo {\n        endCursor\n        hasNextPage\n      }\n    }\n  }\n}\n";
export declare const GroupVulnerabilitiesQuery = "\nquery getGroupVulnerabilities($groupFullPath: ID!, $severities: [VulnerabilitySeverity!], $states: [VulnerabilityState!], $reportTypes: [VulnerabilityReportType!], $first: Int!, $cursor: String) {\n  group(fullPath: $groupFullPath) {\n    vulnerabilities(severity: $severities, state: $states, reportType: $reportTypes, first: $first, after: $cursor) {\n      nodes {\n        project {\n          id\n          fullPath\n        }\n        uuid\n        reportType\n        severity\n        state\n        title\n        scanner {\n          externalId\n          name\n          vendor\n        }\n        identifiers {\n          externalId\n        }\n        falsePositive\n        dismissalReason\n        links {\n          url\n        }\n        solution\n        vulnerabilityPath\n      }\n      pageInfo {\n        endCursor\n        hasNextPage\n      }\n    }\n  }\n}\n";
export declare const ProjectLabelsQuery = "\nquery getProjectLabels($projectFullPath: ID!, $first: Int!, $cursor: String) {\n  project(fullPath: $projectFullPath) {\n    labels(first: $first, after: $cursor) {\n      nodes {\n        id\n        title\n        color\n        textColor\n        description\n        lockOnMerge\n      }\n      pageInfo {\n        endCursor\n        hasNextPage\n      }\n    }\n  }\n}\n";
export declare const ProjectMergeRequestsQuery = "\nquery getProjectMergeRequests($projectFullPath: ID!, $updatedAfter: Time!, $first: Int!, $cursor: String) {\n  project(fullPath: $projectFullPath) {\n    mergeRequests(updatedAfter: $updatedAfter, first: $first, after: $cursor) {\n      nodes {\n        id\n        iid\n        projectId\n        title\n        state\n        sourceBranch\n        targetBranch\n        createdAt\n        updatedAt\n        author {\n          id\n          name\n          username\n        }\n        webUrl\n        mergeWhenPipelineSucceeds\n        shouldRemoveSourceBranch\n        forceRemoveSourceBranch\n        allowCollaboration\n        squash\n        approved\n        approvedBy {\n          nodes {\n            id\n            name\n            username\n          }\n        }\n        mergedAt\n        diffHeadSha\n        mergeCommitSha\n      }\n      pageInfo {\n        endCursor\n        hasNextPage\n      }\n    }\n  }\n}\n";
export declare const MergeRequestCommitsQuery = "\nquery getMergeRequestCommits($mergeRequestId: MergeRequestID!, $first: Int!, $cursor: String) {\n  mergeRequest(id: $mergeRequestId) {\n    commits(first: $first, after: $cursor) {\n      nodes {\n        id\n        shortId\n        title\n        committedDate\n        webUrl\n        message\n        authoredDate\n        committerName\n        committerEmail\n        authorName\n        authorEmail\n      }\n      pageInfo {\n        endCursor\n        hasNextPage\n      }\n    }\n  }\n}\n";
export declare const ProjectBranchRulesQuery = "\nquery getProjectBranchRules($projectFullPath: ID!, $first: Int!, $cursor: String) {\n  project(fullPath: $projectFullPath) {\n    branchRules(first: $first, after: $cursor) {\n      nodes {\n        id\n        name\n        isDefault\n        isProtected\n        createdAt\n        updatedAt\n        matchingBranchesCount\n        branchProtection {\n          allowForcePush\n          codeOwnerApprovalRequired\n          mergeAccessLevels {\n            nodes {\n              accessLevelDescription\n              group {\n                id\n              }\n              user {\n                id\n              }\n            }\n          }\n          pushAccessLevels {\n            nodes {\n              accessLevelDescription\n              group {\n                id\n              }\n              user {\n                id\n              }\n            }\n          }\n        }\n      }\n      pageInfo {\n        endCursor\n        hasNextPage\n      }\n    }\n  }\n}\n";
//# sourceMappingURL=graphqlQueries.d.ts.map